Rigid Body Dynamics Algorithms
==============================

This module provides a set of algorithms for rigid body dynamics.

.. currentmodule:: jaxsim.rbda

.. autosummary::
    :toctree: _autosummary

    aba
    collidable_points
    contacts.soft
    crba
    forward_kinematics
    jacobian
    utils

Collision Detection
~~~~~~~~~~~~~~~~~~~

.. automodule:: jaxsim.rbda.collidable_points
    :members:
    :no-index:

Contact Models
~~~~~~~~~~~~~~

.. automodule:: jaxsim.rbda.contacts.soft
    :members:
    :no-index:

Utilities
~~~~~~~~~

.. automodule:: jaxsim.rbda.utils
    :members:
    :no-index:
